#!/usr/bin/python3

import sys

if sys.version_info[0] < 3:
    raise Exception("Python 3 or a more recent version is required.")

import pytest
import os
from urllib.parse import urlencode
from urllib.request import Request, urlopen
from os.path import join, dirname

def test_service_names(telegraf_agent_config):
    print(telegraf_agent_config['hosts'][0]['name'])
    assert telegraf_agent_config['hosts'][0]['name'] == 'clmc-service'
    assert telegraf_agent_config['hosts'][1]['name'] == 'apache'
    assert telegraf_agent_config['hosts'][2]['name'] == 'nginx' 
    assert telegraf_agent_config['hosts'][3]['name'] == 'mongo'  
    assert telegraf_agent_config['hosts'][4]['name'] == 'ffmpeg'                
    assert telegraf_agent_config['hosts'][5]['name'] == 'ipendpoint'  

def test_ping(telegraf_agent_config):
    """This test will only run on linux"""
    for x in telegraf_agent_config['hosts']:
        print("Testing service" + x['name'] + " " + x['ip_address'])
        response = os.system("ping -c 1 " + x['ip_address'])
        assert response == 0, "Could not ping " + x['name'] + " on ip address " + x['ip_address']

@pytest.mark.parametrize("queries", 
    [{'nginx': {'measurement': 'nginx', 'query': 'SELECT mean("requests") AS "mean_active" FROM "CLMCMetrics"."autogen"."nginx"', 'result': '1'}}])
def test_nginx(telegraf_agent_config, queries):

    measurements = send_query("http://localhost:8086", 'SHOW measurements ON "CLMCMetrics"') 
    assert queries['nginx']['measurement'] in measurements, "Measurement " + measurement + " not in the CLMCMetrics database"

    result = send_query("http://localhost:8086", queries['nginx']['query'])
    print("result" + result)
    # assert results is correct
    
def send_query(url, query):
    """
    An auxiliary static method to send a query to a url and retrieve the result

    :param url: the target url to which the query is sent to - a string containing a valid URL address
    :param query: the query to be executed on the given URL
    :return: the result of the executed query
    """
    query = urlencode({"q": query}).encode("ascii")
    request = Request("{0}/query".format(url), query)
    result = urlopen(request)

    return result.read().decode("utf-8").strip()
